@@ -97,6 +97,16 @@ class BaseExecutor:
 
     @property
     def step_decorator_run_id(self):
+        """
+        TODO: Experimental feature, design is not mature yet.
+
+        This function is used by the decorator function.
+        The design idea is we can over-ride this method in different implementations to retrieve the run_id.
+        But is it really intrusive to ask to set the environmental variable MAGNUS_RUN_ID?
+
+        Returns:
+            _type_: _description_
+        """
         return os.environ.get('MAGNUS_RUN_ID', None)
 
     def _is_parallel_execution(self) -> bool:
@@ -242,6 +252,10 @@ class BaseExecutor:
 
         return data_catalogs
 
+    @property
+    def step_attempt_number(self) -> int:
+        return int(os.environ.get(defaults.ATTEMPT_NUMBER, 1))
+
     def _execute_node(self, node: BaseNode, map_variable: dict = None, **kwargs):
         """
         This is the entry point when we do the actual execution of the function.
@@ -260,11 +274,7 @@ class BaseExecutor:
             node (Node): The node to execute
             map_variable (dict, optional): If the node is of a map state, map_variable is the value of the iterable.
                         Defaults to None.
-
-        #TODO: The attempts should ideally by handled outside of this function
         """
-        max_attempts = node._get_max_attempts()
-        attempts = 0
         step_log = self.run_log_store.get_step_log(node._get_step_log_name(map_variable), self.run_id)
 
         parameters = self.run_log_store.get_parameters(run_id=self.run_id)
@@ -272,42 +282,45 @@ class BaseExecutor:
         # If the key already exists, do not update it to give priority to parameters set by environment variables
         interaction.store_parameter(update=False, **parameters)
 
-        data_catalogs_get: List[DataCatalog] = []
+        parameters_in = utils.get_user_set_parameters(remove=False)
 
-        mock = step_log.mock
-        logger.info(f'Trying to execute node: {node.internal_name}, attempt : {attempts}, max_attempts: {max_attempts}')
-        while attempts < max_attempts:
-            try:
-                if not data_catalogs_get:
-                    data_catalogs_get = self._sync_catalog(node, step_log, stage='get')
+        attempt = self.step_attempt_number
+        max_attempts = max_attempts = node._get_max_attempts()
+        logger.info(f'Trying to execute node: {node.internal_name}, attempt : {attempt}, max_attempts: {max_attempts}')
 
-                self.context_step_log = step_log
-                attempt_log = node.execute(executor=self, mock=mock,
-                                           map_variable=map_variable, **kwargs)
-                attempt_log.attempt_number = attempts
-                step_log.attempts.append(attempt_log)
-                if attempt_log.status == defaults.FAIL:
-                    raise Exception()
+        data_catalogs_get: List[DataCatalog] = self._sync_catalog(node, step_log, stage='get')
+        attempt_log = self.run_log_store.create_attempt_log()
+        try:
+            self.context_step_log = step_log
+            attempt_log = node.execute(executor=self, mock=step_log.mock, map_variable=map_variable, **kwargs)
+        except Exception as e:
+            # Any exception here is a magnus exception as node suppresses exceptions.
+            msg = (
+                f"This is clearly magnus fault, please report a bug and the logs"
+            )
+            raise Exception(msg) from e
+        finally:
+            attempt_log.attempt_number = attempt
+            attempt_log.parameters = parameters_in
+            step_log.attempts.append(attempt_log)
 
-                step_log.status = defaults.SUCCESS
-                step_log.user_defined_metrics = utils.get_tracked_data()
-                self.run_log_store.set_parameters(self.run_id, utils.get_user_set_parameters(remove=True))
-                self._sync_catalog(node, step_log, stage='put', synced_catalogs=data_catalogs_get)
-                break
-            except Exception as _e:  # pylint: disable=W0703
-                attempts += 1
-                logger.exception(f'Node: {node} failed with exception {_e}')
-                # Remove any steps data
-                utils.get_tracked_data()
-                utils.get_user_set_parameters(remove=True)
-            finally:
-                self.context_step_log = None  # type: ignore
+            tracked_data = utils.get_tracked_data()
+            parameters_out = utils.get_user_set_parameters(remove=True)
 
-            if attempts == max_attempts:
+            if attempt_log.status == defaults.FAIL:
+                logger.exception(f'Node: {node} failed')
                 step_log.status = defaults.FAIL
-                logger.error(f'Node {node} failed, max retries of {max_attempts} reached')
+            else:
+                step_log.status = defaults.SUCCESS
+                self._sync_catalog(node, step_log, stage='put', synced_catalogs=data_catalogs_get)
+                step_log.user_defined_metrics = tracked_data
+                diff_parameters = utils.diff_dict(parameters_in, parameters_out)
+                self.run_log_store.set_parameters(self.run_id, diff_parameters)
 
-        self.run_log_store.add_step_log(step_log, self.run_id)
+            # Remove the step log context
+            self.context_step_log = None
+
+            self.run_log_store.add_step_log(step_log, self.run_id)
 
     def execute_node(self, node: BaseNode, map_variable: dict = None, **kwargs):
         raise NotImplementedError
@@ -477,6 +490,10 @@ class BaseExecutor:
             branch = working_on.internal_branch_name
 
         logger.info(f'Finished execution of the {branch} with status {run_log.status}')
+
+        # get the final run log
+        if branch == 'graph':
+            run_log = self.run_log_store.get_run_log_by_id(run_id=self.run_id, full=True)
         print(json.dumps(run_log.dict(), indent=4))
 
     def _is_eligible_for_rerun(self, node: BaseNode, map_variable: dict = None):
