@@ -614,7 +614,10 @@ def get_run_config(executor: BaseExecutor) -> dict:
     run_config['experiment_tracker'] = {'type': executor.experiment_tracker.service_name,
                                         'config': executor.experiment_tracker.config}
     run_config['variables'] = executor.variables  # type: ignore
-    run_config['pipeline'] = executor.dag._to_dict()
+
+    if executor.dag:
+        # Notebook and functions do not have dag's defined
+        run_config['pipeline'] = executor.dag._to_dict()
 
     return run_config
 
